==> JDFLibJ-2.1.5.90-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/jdftoxjdf/WalkMessage.java <==
/**
 * The CIP4 Software License, Version 1.0
 *
 * Copyright (c) 2001-2015 The International Cooperation for the Integration of 
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of 
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of 
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration 
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software 
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG 
 * copyright (c) 1999-2001, Agfa-Gevaert N.V. 
 *  
 * For more information on The International Cooperation for the 
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *  
 * 
 */
package org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf;

import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.jmf.JDFMessage;
import org.cip4.jdflib.jmf.JDFMessage.EnumFamily;

/**
 * @author Rainer Prosi, Heidelberger Druckmaschinen <br/>
 * walker for JMF mesaages
 */
public class WalkMessage extends WalkJDFElement
{
	/**
	 * 
	 */
	public WalkMessage()
	{
		super();
	}

	/**
	 * @param jdf
	 * @return the created message
	 */
	@Override
	public KElement walk(final KElement jdf, final KElement xjdf)
	{
		JDFMessage m = (JDFMessage) jdf;
		if (jdfToXJDF.isTypeSafeMessage())
		{
			makeTypesafe(m);
		}
		return super.walk(jdf, xjdf);
	}

	/**
	 * 
	 * @param m
	 */
	void makeTypesafe(JDFMessage m)
	{
		EnumFamily family = getNewFamily(m);
		if (family == null)
		{
			log.error("cannot convert message with null family");
		}
		else
		{
			String type = getMessageType(m);
			m.renameElement(getFamilyName(family) + type, null);
		}
	}

	/**
	 * 
	 * @param family
	 * @return
	 */
	String getFamilyName(EnumFamily family)
	{
		return family.getName();
	}

	/**
	 * 
	 * @param m
	 * @return
	 */
	String getMessageType(JDFMessage m)
	{
		String type = m.getType();
		return type;
	}

	/**
	 * 
	 *  
	 * @param m
	 * @return
	 */
	private EnumFamily getNewFamily(JDFMessage m)
	{
		EnumFamily family = m.getFamily();
		if (jdfToXJDF.isAbstractMessage())
		{
			if (EnumFamily.Command.equals(family) || EnumFamily.Registration.equals(family))
				family = EnumFamily.Query;
			if (EnumFamily.Acknowledge.equals(family))
				family = EnumFamily.Response;
		}
		return family;
	}

	/**
	 * 
	 * @see org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf.WalkJDFElement#removeUnused(org.cip4.jdflib.core.KElement)
	 */
	@Override
	protected void removeUnused(final KElement newRootP)
	{
		super.removeUnused(newRootP);
		if (jdfToXJDF.isTypeSafeMessage())
		{
			newRootP.removeAttribute(AttributeName.TYPE);
		}
	}

	/**
	 * @see org.cip4.jdflib.elementwalker.BaseWalker#matches(org.cip4.jdflib.core.KElement)
	 * @param toCheck
	 * @return true if it matches
	 */
	@Override
	public boolean matches(final KElement toCheck)
	{
		return (toCheck instanceof JDFMessage);
	}
}

==> JDFLibJ-2.1.6.0-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/jdftoxjdf/WalkMessage.java <==
/**
 * The CIP4 Software License, Version 1.0
 *
 * Copyright (c) 2001-2018 The International Cooperation for the Integration of
 * Processes in  Prepress, Press and Postpress (CIP4).  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        The International Cooperation for the Integration of
 *        Processes in  Prepress, Press and Postpress (www.cip4.org)"
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of
 *    Processes in  Prepress, Press and Postpress" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4",
 *    nor may "CIP4" appear in their name, without prior written
 *    permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For
 * details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR
 * THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the The International Cooperation for the Integration
 * of Processes in Prepress, Press and Postpress and was
 * originally based on software
 * copyright (c) 1999-2001, Heidelberger Druckmaschinen AG
 * copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the
 * Integration of Processes in  Prepress, Press and Postpress , please see
 * <http://www.cip4.org/>.
 *
 *
 */
package org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf;

import org.cip4.jdflib.core.AttributeName;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.datatypes.JDFAttributeMap;
import org.cip4.jdflib.jmf.JDFMessage;
import org.cip4.jdflib.jmf.JDFMessage.EnumFamily;
import org.cip4.jdflib.jmf.JDFMessage.EnumType;
import org.cip4.jdflib.util.StringUtil;

/**
 * @author Rainer Prosi, Heidelberger Druckmaschinen <br/>
 * walker for JMF mesaages
 */
public class WalkMessage extends WalkJDFElement
{
	/**
	 *
	 */
	public WalkMessage()
	{
		super();
	}

	/**
	 * @param jdf
	 * @return the created message
	 */
	@Override
	public KElement walk(final KElement jdf, final KElement xjdf)
	{
		final JDFMessage m = (JDFMessage) jdf;

		if (jdfToXJDF.isTypeSafeMessage())
		{
			final JDFMessage m2 = makeTypesafe(m);
			if (m2 == null)
			{
				return null;
			}
		}
		return super.walk(jdf, xjdf);
	}

	/**
	 * @see org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf.WalkElement#updateAttributes(org.cip4.jdflib.datatypes.JDFAttributeMap)
	 */
	@Override
	protected void updateAttributes(final JDFAttributeMap map)
	{
		super.updateAttributes(map);
		if (jdfToXJDF.isTypeSafeMessage())
		{
			map.renameKey(AttributeName.SENDERID, AttributeName.DEVICEID);
			map.remove(AttributeName.TYPE);
			map.remove(AttributeName.ACKNOWLEDGED);
			map.remove(AttributeName.ACKNOWLEDGETYPE);
			map.remove(AttributeName.ACKNOWLEDGEURL);
			map.remove(AttributeName.FORMAT);
			map.remove(AttributeName.LASTREPEAT);
			map.remove(AttributeName.TEMPLATE);
		}

	}

	/**
	 *
	 * @param m
	 */
	JDFMessage makeTypesafe(final JDFMessage m)
	{
		final EnumFamily family = getNewFamily(m);
		final String type = family == null ? null : getMessageType(m);
		if (type == null)
		{
			return null;
		}
		else
		{
			m.renameElement(getFamilyName(family) + type, null);
		}
		return m;
	}

	/**
	 *
	 * @param family
	 * @return
	 */
	String getFamilyName(final EnumFamily family)
	{
		return family.getName();
	}

	/**
	 *
	 * @param m
	 * @return
	 */
	String getMessageType(final JDFMessage m)
	{
		final EnumType type = m.getEnumType();
		final boolean zappType = isZappType(type);
		if (zappType)
		{
			log.warn("Removing unsupported message Type: " + m.getType());
		}
		return zappType ? null : type.getName();
	}

	/**
	 *
	 * @param type
	 * @return
	 */
	boolean isZappType(final EnumType type)
	{
		return EnumType.CloseQueue.equals(type) || EnumType.Events.equals(type) || EnumType.FlushResources.equals(type) || EnumType.HoldQueue.equals(type)
				|| EnumType.KnownControllers.equals(type) || EnumType.KnownJDFServices.equals(type) || EnumType.ModifyNode.equals(type) || EnumType.NewJDF.equals(type)
				|| EnumType.NodeInfo.equals(type) || EnumType.Occupation.equals(type) || EnumType.OpenQueue.equals(type) || EnumType.QueueEntryStatus.equals(type)
				|| EnumType.RepeatMessages.equals(type) || EnumType.RequestForAuthentication.equals(type) || EnumType.ResumeQueue.equals(type)
				|| EnumType.SubmissionMethods.equals(type) || EnumType.Track.equals(type) || EnumType.UpdateJDF.equals(type);
	}

	/**
	 *
	 *
	 * @param m
	 * @return
	 */
	EnumFamily getNewFamily(final JDFMessage m)
	{
		final String type = m.getType();
		if (StringUtil.isEmpty(type))
		{
			return null;
		}
		EnumFamily family = m.getFamily();
		if (jdfToXJDF.isAbstractMessage())
		{
			if (EnumFamily.Command.equals(family) || EnumFamily.Registration.equals(family))
				family = EnumFamily.Query;
			if (EnumFamily.Acknowledge.equals(family))
				family = EnumFamily.Response;
		}
		return family;
	}

	/**
	 * @see org.cip4.jdflib.elementwalker.BaseWalker#matches(org.cip4.jdflib.core.KElement)
	 * @param toCheck
	 * @return true if it matches
	 */
	@Override
	public boolean matches(final KElement toCheck)
	{
		return (toCheck instanceof JDFMessage);
	}
}
